Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(72)

Unified Diff: Source/WebKit/chromium/src/WebViewImpl.cpp

Issue 7316012: Merge 90185 - 2011-06-30 John Bates <jbates@google.com> (Closed) Base URL: http://svn.webkit.org/repository/webkit/branches/chromium/782/
Patch Set: Created 9 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/WebKit/chromium/ChangeLog ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/WebKit/chromium/src/WebViewImpl.cpp
===================================================================
--- Source/WebKit/chromium/src/WebViewImpl.cpp (revision 90510)
+++ Source/WebKit/chromium/src/WebViewImpl.cpp (working copy)
@@ -1144,15 +1144,19 @@
m_recreatingGraphicsContext = false;
return;
}
- doComposite();
- // Finish if requested.
- if (finish)
- m_layerRenderer->finish();
+ // Do not composite if the compositor context is already lost.
+ if (!m_layerRenderer->isCompositorContextLost()) {
+ doComposite();
- // Put result onscreen.
- m_layerRenderer->present();
+ // Finish if requested.
+ if (finish)
+ m_layerRenderer->finish();
+ // Put result onscreen.
+ m_layerRenderer->present();
+ }
+
if (m_layerRenderer->isCompositorContextLost()) {
// Trying to recover the context right here will not work if GPU process
// died. This is because GpuChannelHost::OnErrorMessage will only be
« no previous file with comments | « Source/WebKit/chromium/ChangeLog ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698